VariadicRef

Trait VariadicRef 

pub trait VariadicRef:
    Clone
    + Debug
    + PartialEq {
    // Required method
    fn size_in_bytes(&self) -> usize;
}
A type used as element of MultiArrayView.

Implemented by an enum type.

Required Methods

fn size_in_bytes(&self) -> usize

Returns size in bytes of the current variant type.

Since a variadic struct can contain types of different sized, this is a method based on the current value type.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors